@@ -10,21 +10,15 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn key_input(
-        &mut self,
-        window: &wita::Window,
-        code: wita::KeyCode,
-        state: wita::KeyState,
-        _: bool,
-    ) {
-        if state == wita::KeyState::Pressed {
-            match code.vkey {
-                wita::VirtualKey::Char('Q') => window.close(),
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.state == wita::KeyState::Pressed {
+            match ev.key_code.vkey {
+                wita::VirtualKey::Char('Q') => ev.window.close(),
                 wita::VirtualKey::Char('T') => {
-                    if window.style().is_borderless() {
-                        window.set_style(wita::WindowStyle::default());
+                    if ev.window.style().is_borderless() {
+                        ev.window.set_style(wita::WindowStyle::default());
                     } else {
-                        window.set_style(wita::WindowStyle::borderless());
+                        ev.window.set_style(wita::WindowStyle::borderless());
                     }
                 }
                 _ => (),
