@@ -14,16 +14,10 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn key_input(
-        &mut self,
-        window: &wita::Window,
-        code: wita::KeyCode,
-        state: wita::KeyState,
-        _: bool,
-    ) {
-        if code.vkey == wita::VirtualKey::F(1) && state == wita::KeyState::Released {
-            let flag = !window.is_enabled_ime();
-            window.ime(flag);
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.key_code.vkey == wita::VirtualKey::F(1) && ev.state == wita::KeyState::Released {
+            let flag = !ev.window.is_enabled_ime();
+            ev.window.ime(flag);
             if flag {
                 println!("enabled ime");
             } else {
@@ -32,21 +26,19 @@ impl wita::EventHandler for Application {
         }
     }
 
-    fn ime_start_composition(&mut self, _: &wita::Window) {
+    fn ime_start_composition(&mut self, _: wita::event::ImeStartComposition) {
         println!("ime start composition");
     }
 
-    fn ime_composition(
-        &mut self,
-        _: &wita::Window,
-        comp: &wita::ime::Composition,
-        candidate: Option<&wita::ime::CandidateList>,
-    ) {
-        println!("ime composition: {:?} {:?}", comp, candidate);
+    fn ime_composition(&mut self, ev: wita::event::ImeComposition) {
+        println!(
+            "ime composition: {:?} {:?}",
+            ev.composition, ev.candidate_list
+        );
     }
 
-    fn ime_end_composition(&mut self, _: &wita::Window, s: Option<&str>) {
-        println!("ime end composition: {:?}", s);
+    fn ime_end_composition(&mut self, ev: wita::event::ImeEndComposition) {
+        println!("ime end composition: {:?}", ev.result);
     }
 }
 
