@@ -13,23 +13,17 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn key_input(
-        &mut self,
-        window: &wita::Window,
-        code: wita::KeyCode,
-        state: wita::KeyState,
-        _: bool,
-    ) {
-        if state == wita::KeyState::Pressed {
-            match code.vkey {
-                wita::VirtualKey::Char('Q') => window.close(),
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.state == wita::KeyState::Pressed {
+            match ev.key_code.vkey {
+                wita::VirtualKey::Char('Q') => ev.window.close(),
                 wita::VirtualKey::Char('T') => {
                     if !self.frame {
-                        window.set_style(wita::WindowStyle::dialog());
+                        ev.window.set_style(wita::WindowStyle::dialog());
                     } else {
-                        window.set_style(wita::WindowStyle::borderless());
+                        ev.window.set_style(wita::WindowStyle::borderless());
                     }
-                    println!("{:?}", window.position());
+                    println!("{:?}", ev.window.position());
                     self.frame = !self.frame;
                 }
                 _ => (),
