@@ -336,7 +336,7 @@ pub fn get_key_state(k: VirtualKey) -> bool {
 pub fn keyboard_state(keys: &mut Vec<VirtualKey>) {
     let mut buffer = [0u8; 256];
     unsafe {
-        GetKeyboardState(buffer.as_mut_ptr());
+        GetKeyboardState(&mut buffer);
     }
     keys.clear();
     for (i, k) in buffer.iter().enumerate() {
@@ -500,7 +500,7 @@ impl Cursor {
     #[inline]
     pub(crate) fn set(&self) {
         unsafe {
-            SetCursor(LoadCursorW(HINSTANCE::default(), self.name()));
+            SetCursor(LoadCursorW(HINSTANCE::default(), self.name()).unwrap());
         }
     }
 }
