@@ -38,7 +38,7 @@ pub struct Moved<'a> {
 /// `EventHandler::resizing` parameters.
 pub struct Resizing<'a> {
     pub window: &'a Window,
-    pub size: PhysicalSize<u32>,
+    pub size: &'a mut PhysicalSize<u32>,
 }
 
 /// `EventHandler::resized` parameters.
@@ -47,6 +47,23 @@ pub struct Resized<'a> {
     pub size: PhysicalSize<u32>,
 }
 
+/// `EventHandler::minimized` parameters.
+pub struct Minimized<'a> {
+    pub window: &'a Window,
+}
+
+/// `EventHandler::maximized` parameters.
+pub struct Maximized<'a> {
+    pub window: &'a Window,
+    pub size: PhysicalSize<u32>,
+}
+
+/// `EventHandler::restored` parameters.
+pub struct Restored<'a> {
+    pub window: &'a Window,
+    pub size: PhysicalSize<u32>,
+}
+
 /// `EventHandler::dpi_changed` parameters.
 pub struct DpiChanged<'a> {
     pub window: &'a Window,
@@ -188,6 +205,15 @@ pub trait EventHandler {
     /// This is called when the window has been resized.
     fn resized(&mut self, ev: Resized) {}
 
+    /// This is called when the window has been minimized.
+    fn minimized(&mut self, ev: Minimized) {}
+
+    /// This is called when the window has been maximized.
+    fn maximized(&mut self, ev: Maximized) {}
+
+    /// This is called when the window has been restored from the minimize or maximize window.
+    fn restored(&mut self, ev: Restored) {}
+
     /// This is called when the window's DPI has been changed.
     fn dpi_changed(&mut self, ev: DpiChanged) {}
 
