@@ -103,6 +103,14 @@ fn mouse_input<T: EventHandler + 'static>(
     lparam: LPARAM,
 ) -> LRESULT {
     call_handler(|eh: &mut T, state| {
+        match button_state {
+            KeyState::Pressed => unsafe {
+                SetCapture(HWND(window.raw_handle() as _));
+            },
+            KeyState::Released => unsafe {
+                ReleaseCapture();
+            },
+        }
         let buttons = &mut state.mouse_buttons;
         update_buttons(buttons, wparam);
         let ev = event::MouseInput {
